==> digikam-4.11.0.tar.bz2: digikam-4.11.0/extra/kipi-plugins/vkontakte/kipiplugin_vkontakte.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=VKontakte.ru Exporter
Name=VKontakte.ru Exporter
Name[bs]=VKontakte.ru Izvoznik
Name[ca]=Exportador a VKontakte.ru
Name[ca@valencia]=Exportador a VKontakte.ru
Name[cs]=Exportér VKontakte.ru
Name[da]=Eksportør til VKontakte.ru
Name[de]=VKontakte.ru-Export
Name[el]=Εξαγωγέας VKontakte.ru 
Name[en_GB]=VKontakte.ru Exporter
Name[es]=Exportar a VKontakte.ru
Name[et]=VKontakte.ru eksportija
Name[fi]=VKontakte.ru-vienti
Name[fr]=Outil d'exportation « VKontakte.ru »
Name[ga]=Easpórtálaí VKontakte.ru
Name[gl]=Exportador a VKontackte.ru
Name[hu]=VKontakte.ru exportáló
Name[is]=VKontakte.ru útflutningstól
Name[it]=Esportatore a VKontakte.ru
Name[km]=កម្មវិធី​នាំចេញ VKontakte.ru
Name[nb]=VKontakte.ru eksporterer
Name[nl]=Exportprogramma van VKontakte.ru
Name[pl]=Eksporter VKontakte.ru
Name[pt]=Exportação para o VKontakte.ru
Name[pt_BR]=Exportar para o VKontakte.ru
Name[ru]=Экспорт в ВКонтакте
Name[sk]=VKontakte.ru exportovač
Name[sl]=Izvoz v VKontakte.ru
Name[sv]=Export till VKontakte.ru
Name[tr]=VKontakte.ru Aktarıcı
Name[uk]=Експорт до VKontakte.ru
Name[x-test]=xxVKontakte.ru Exporterxx
Name[zh_TW]=Vkontakte.ru 匯出器
Comment=A tool to export images to the VKontakte.ru social network
Comment[bs]=Alat za izvoz slike u VKontakte.ru društvenoj mreži
Comment[ca]=Una eina per exportar imatges a la xarxa social VKontakte.ru
Comment[ca@valencia]=Una eina per exportar imatges a la xarxa social VKontakte.ru
Comment[cs]=Nástroj pro export obrázků do sociální sítě VKontakte.ru
Comment[da]=Et værktøj til at eksportere billeder til det sociale netværk VKontakte.ru
Comment[de]=Ein Werkzeug, um Bilder zum Sozialen Netzwerk „VKontakte“ zu exportieren.
Comment[el]=Ένα εργαλείο εξαγωγής εικόνων στο κοινωνικό δίκτυο VKontakte.ru
Comment[en_GB]=A tool to export images to the VKontakte.ru social network
Comment[es]=Herramienta para exportar imágenes a la red social VKontakte.ru
Comment[et]=Tööriist piltide eksportimiseks VKontakte.ru sotsiaalvõrgustikku
Comment[fi]=Kuvien vienti Vkontakte.ru-nimiseen sosiaaliseen verkkoon
Comment[fr]=Un outil d'exportation d'images vers le réseau social « VKontakte.ru »
Comment[ga]=Uirlis a easpórtálann íomhánna go dtí an líonra sóisialta VKontakte.ru
Comment[gl]=Unha ferramenta para exportar imaxes á rede social VKontakte.ru
Comment[hu]=Egy eszköz képek exportálásához a VKontakte.ru közösségi hálózatba
Comment[is]=Verkfæri til að senda myndir VKontakte.ru samskiptanetið
Comment[it]=Uno strumento per esportare immagini alla rete sociale VKontakte.ru
Comment[km]=ឧបករណ៍​ត្រូវ​នាំរូបភាព​ចេញ​ទៅ​បណ្ដាញ​សង្គម VKontakte.ru
Comment[nb]=Et verktøy for å eksportere bilder til det sosiale nettverket VKontakte.ru
Comment[nl]=Een hulpmiddel om afbeeldingen te exporteren naar het VKontakte.ru sociale netwerk
Comment[pl]=Narzędzie do eksportowania obrazów do sieci społecznej VKontakte.ru
Comment[pt]=Uma ferramenta para exportar imagens para a rede social VKontakte.ru
Comment[pt_BR]=Ferramenta para exportar imagens para a rede social VKontakte.ru
Comment[ru]=Инструмент для экспорта изображений в социальную сеть VKontakte.ru
Comment[sk]=Nástroj na export obrázkov na sociálnu sieť VKontakte.ru
Comment[sl]=Orodje za izvoz slik v družabno omrežje VKontakte.ru
Comment[sv]=Ett verktyg för att exportera bilder till sociala nätverket VKontakte.ru
Comment[tr]=Resimleri VKontakte.ru sosyal ağına aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображень до соціальної мережі VKontakte.ru
Comment[x-test]=xxA tool to export images to the VKontakte.ru social networkxx
Comment[zh_TW]=匯出影像到 Vkontakte.ru 社交網路的工具
Type=Service
Icon=preferences-web-browser-shortcuts
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_vkontakte
author=Alexander Potashev, aspotashev at gmail dot com
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}

==> digikam-4.14.0.tar.bz2: digikam-4.14.0/extra/kipi-plugins/vkontakte/kipiplugin_vkontakte.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=VKontakte.ru Exporter
Name=VKontakte.ru Exporter
Name[bs]=VKontakte.ru Izvoznik
Name[ca]=Exportador a VKontakte.ru
Name[ca@valencia]=Exportador a VKontakte.ru
Name[cs]=Exportér VKontakte.ru
Name[da]=Eksportør til VKontakte.ru
Name[de]=VKontakte.ru-Export
Name[el]=Εξαγωγέας VKontakte.ru 
Name[en_GB]=VKontakte.ru Exporter
Name[es]=Exportar a VKontakte.ru
Name[et]=VKontakte.ru eksportija
Name[fi]=VKontakte.ru-vienti
Name[fr]=Outil d'export « VKontakte.ru »
Name[ga]=Easpórtálaí VKontakte.ru
Name[gl]=Exportador a VKontackte.ru
Name[hu]=VKontakte.ru exportáló
Name[is]=VKontakte.ru útflutningstól
Name[it]=Esportatore a VKontakte.ru
Name[km]=កម្មវិធី​នាំចេញ VKontakte.ru
Name[nb]=VKontakte.ru eksporterer
Name[nl]=Exportprogramma van VKontakte.ru
Name[pl]=Eksporter VKontakte.ru
Name[pt]=Exportação para o VKontakte.ru
Name[pt_BR]=Exportar para o VKontakte.ru
Name[ru]=Экспорт в ВКонтакте
Name[sk]=VKontakte.ru exportovač
Name[sl]=Izvoz v VKontakte.ru
Name[sv]=Export till VKontakte.ru
Name[tr]=VKontakte.ru Aktarıcı
Name[uk]=Експорт до VKontakte.ru
Name[x-test]=xxVKontakte.ru Exporterxx
Name[zh_TW]=Vkontakte.ru 匯出器
Comment=A tool to export images to the VKontakte.ru social network
Comment[bs]=Alat za izvoz slike u VKontakte.ru društvenoj mreži
Comment[ca]=Una eina per exportar imatges a la xarxa social VKontakte.ru
Comment[ca@valencia]=Una eina per exportar imatges a la xarxa social VKontakte.ru
Comment[cs]=Nástroj pro export obrázků do sociální sítě VKontakte.ru
Comment[da]=Et værktøj til at eksportere billeder til det sociale netværk VKontakte.ru
Comment[de]=Ein Werkzeug, um Bilder zum Sozialen Netzwerk „VKontakte“ zu exportieren.
Comment[el]=Ένα εργαλείο εξαγωγής εικόνων στο κοινωνικό δίκτυο VKontakte.ru
Comment[en_GB]=A tool to export images to the VKontakte.ru social network
Comment[es]=Herramienta para exportar imágenes a la red social VKontakte.ru
Comment[et]=Tööriist piltide eksportimiseks VKontakte.ru sotsiaalvõrgustikku
Comment[fi]=Kuvien vienti Vkontakte.ru-nimiseen sosiaaliseen verkkoon
Comment[fr]=Un outil d'export d'images vers le réseau social « VKontakte.ru »
Comment[ga]=Uirlis a easpórtálann íomhánna go dtí an líonra sóisialta VKontakte.ru
Comment[gl]=Unha ferramenta para exportar imaxes á rede social VKontakte.ru
Comment[hu]=Egy eszköz képek exportálásához a VKontakte.ru közösségi hálózatba
Comment[is]=Verkfæri til að senda myndir VKontakte.ru samskiptanetið
Comment[it]=Uno strumento per esportare immagini alla rete sociale VKontakte.ru
Comment[km]=ឧបករណ៍​ត្រូវ​នាំរូបភាព​ចេញ​ទៅ​បណ្ដាញ​សង្គម VKontakte.ru
Comment[nb]=Et verktøy for å eksportere bilder til det sosiale nettverket VKontakte.ru
Comment[nl]=Een hulpmiddel om afbeeldingen te exporteren naar het VKontakte.ru sociale netwerk
Comment[pl]=Narzędzie do eksportowania obrazów do sieci społecznej VKontakte.ru
Comment[pt]=Uma ferramenta para exportar imagens para a rede social VKontakte.ru
Comment[pt_BR]=Ferramenta para exportar imagens para a rede social VKontakte.ru
Comment[ru]=Инструмент для экспорта изображений в социальную сеть VKontakte.ru
Comment[sk]=Nástroj na export obrázkov na sociálnu sieť VKontakte.ru
Comment[sl]=Orodje za izvoz slik v družabno omrežje VKontakte.ru
Comment[sv]=Ett verktyg för att exportera bilder till sociala nätverket VKontakte.ru
Comment[tr]=Resimleri VKontakte.ru sosyal ağına aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображень до соціальної мережі VKontakte.ru
Comment[x-test]=xxA tool to export images to the VKontakte.ru social networkxx
Comment[zh_TW]=匯出影像到 Vkontakte.ru 社交網路的工具
Type=Service
Icon=preferences-web-browser-shortcuts
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_vkontakte
author=Alexander Potashev, aspotashev at gmail dot com
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
